using NUnit.Framework;
using RebootKit.Engine.Foundation;

namespace Tests.Runtime.Engine {
    public class PredicateTests {
        [Test]
        public void Predicate_And_TwoConditions_IsValid() {
            IPredicate predicate = new PredicateAnd(new[] {
                new PredicateConsts(true),
                new PredicateConsts(true)
            });

            Assert.IsTrue(predicate.Evaluate());
        }
        
        [Test]
        public void Predicate_Or_TwoConditions_IsValid() {
            IPredicate predicate = new PredicateOr(new[] {
                new PredicateConsts(true),
                new PredicateConsts(false)
            });

            Assert.IsTrue(predicate.Evaluate());
        }
    }
}